==============================
Core Functionalities
==============================

.. grid:: 3

    .. grid-item-card:: 
        :octicon:`package;10em`
        :link: labeled_data
        :link-type: doc
        :text-align: center

        **Multi-Dimensional & Labeled Data**

        Perform dimensionality reduction within your familiar xarray ecosystem.

    .. grid-item-card::
        :octicon:`globe;10em`
        :link: dask_support
        :link-type: doc
        :text-align: center

        **Dask Support**

        Process large datasets efficiently with dask xarray objects.
        


    .. grid-item-card::
        :octicon:`rocket;10em`
        :link: efficient
        :link-type: doc
        :text-align: center

        **Computationally Efficient**

        Handle millions of features swiftly using randomized linear algebra.


.. grid:: 3

    .. grid-item-card::
        :octicon:`sync;10em`
        :link: model_serialization
        :link-type: doc
        :text-align: center

        **Model Serialization**

        Save and load models for future analysis.

    .. grid-item-card::
        :octicon:`verified;10em`
        :link: model_evaluation
        :link-type: doc
        :text-align: center

        **Significance Testing**

        Assess the significance of your results with bootstrapping.

    .. grid-item-card::
        :octicon:`key-asterisk;10em`
        :link: missing_values
        :link-type: doc
        :text-align: center

        **Dealing with missing values**

        Manage missing data flexibly within your analysis.


.. toctree::
    :maxdepth: 3
    :hidden:

    labeled_data
    dask_support
    efficient
    model_serialization
    model_evaluation
    missing_values